richardview.built\_in\_widgets package
======================================

Submodules
----------

richardview.built\_in\_widgets.spiciness\_widget module
-------------------------------------------------------

.. automodule:: richardview.built_in_widgets.spiciness_widget
   :members:
   :undoc-members:
   :show-inheritance:

richardview.built\_in\_widgets.title\_widget module
---------------------------------------------------

.. automodule:: richardview.built_in_widgets.title_widget
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: richardview.built_in_widgets
   :members:
   :undoc-members:
   :show-inheritance:
